Exception: Lyft::ThrottleError
- Inherits:
-
StandardError
- Object
- StandardError
- Lyft::ThrottleError
- Defined in:
- lib/lyft/errors.rb
Overview
Raised when we get a throttle error from the API
Raised when we get a throttle error from the API